@@ -2,35 +2,18 @@
 Unittests for the c-bindings
 """
 
-import os
-import sys
-import time
-import json
-import textwrap
 import unittest
+
 import numpy as np
 
 from binarycpython import _binary_c_bindings
-
-from binarycpython.utils.functions import (
-    temp_dir,
-    verbose_print,
-    is_capsule,
-    Capturing,
-)
-from binarycpython.utils.ensemble import (
-    BinarycDecoder,
-    handle_ensemble_string_to_json,
-    extract_ensemble_json_from_string,
-)
-from binarycpython.utils.dicts import (
-    inspect_dict,
-    merge_dicts,
-)
-
+from binarycpython.utils.dicts import merge_dicts
+from binarycpython.utils.ensemble import extract_ensemble_json_from_string
+from binarycpython.utils.functions import Capturing, is_capsule, temp_dir
 
 TMP_DIR = temp_dir("tests", "test_c_bindings")
 
+
 #### some useful functions
 def return_argstring(
     m1=15.0,
@@ -80,7 +63,7 @@ class test_run_system(unittest.TestCase):
     """
 
     def test_output(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_output()
 
     def _test_output(self):
@@ -126,7 +109,7 @@ class test_return_store_memaddr(unittest.TestCase):
     """
 
     def test_return_store_memaddr(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_return_store_memaddr()
 
     def _test_return_store_memaddr(self):
@@ -166,7 +149,7 @@ class test_ensemble_functions(unittest.TestCase):
         super(test_ensemble_functions, self).__init__(*args, **kwargs)
 
     def test_return_persistent_data_memaddr(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_return_persistent_data_memaddr()
 
     def _test_return_persistent_data_memaddr(self):
@@ -180,7 +163,7 @@ class test_ensemble_functions(unittest.TestCase):
         self.assertTrue(is_capsule(output), msg="Object must be a capsule")
 
     def test_minimal_ensemble_output(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_minimal_ensemble_output()
 
     def _test_minimal_ensemble_output(self):
@@ -210,7 +193,7 @@ class test_ensemble_functions(unittest.TestCase):
         self.assertNotEqual(test_json["number_counts"], {})
 
     def test_minimal_ensemble_output_defer(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_minimal_ensemble_output_defer()
 
     def _test_minimal_ensemble_output_defer(self):
@@ -252,7 +235,7 @@ class test_ensemble_functions(unittest.TestCase):
         self.assertNotEqual(ensemble_json_output["number_counts"], {})
 
     def test_add_ensembles_direct(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_add_ensembles_direct()
 
     def _test_add_ensembles_direct(self):
@@ -317,7 +300,7 @@ class test_ensemble_functions(unittest.TestCase):
         )
 
     def test_compare_added_systems_with_double_deferred_systems(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_compare_added_systems_with_double_deferred_systems()
 
     def _test_compare_added_systems_with_double_deferred_systems(self):
@@ -408,7 +391,7 @@ class test_ensemble_functions(unittest.TestCase):
             )
 
     def test_combine_with_empty_json(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_combine_with_empty_json()
 
     def _test_combine_with_empty_json(self):
@@ -438,7 +421,7 @@ class test_ensemble_functions(unittest.TestCase):
     #############
 
     def test_full_ensemble_output(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_full_ensemble_output()
 
     def _test_full_ensemble_output(self):
