@@ -8,31 +8,28 @@ import os
 import unittest
 from collections import OrderedDict
 
-from binarycpython.utils.functions import (
-    temp_dir,
-    Capturing,
-)
 from binarycpython.utils.dicts import (
-    merge_dicts,
-    set_opts,
     AutoVivificationDict,
-    inspect_dict,
-    normalize_dict,
-    filter_dict,
-    filter_dict_through_values,
-    prepare_dict,
-    custom_sort_dict,
-    multiply_values_dict,
-    keys_to_floats,
-    count_keys_recursive,
-    recursive_change_key_to_float,
-    recursive_change_key_to_string,
-    multiply_float_values,
-    subtract_dicts,
-    update_dicts,
     _nested_get,
     _nested_set,
+    count_keys_recursive,
+    custom_sort_dict,
+    filter_dict,
+    filter_dict_through_values,
+    inspect_dict,
+    keys_to_floats,
+    merge_dicts,
+    multiply_float_values,
+    multiply_values_dict,
+    normalize_dict,
+    prepare_dict,
+    recursive_change_key_to_float,
+    recursive_change_key_to_string,
+    set_opts,
+    subtract_dicts,
+    update_dicts,
 )
+from binarycpython.utils.functions import Capturing, temp_dir
 
 TMP_DIR = temp_dir("tests", "test_dicts")
 
@@ -61,7 +58,7 @@ class test_merge_dicts(unittest.TestCase):
     """
 
     def test_empty(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_empty()
 
     def _test_empty(self):
@@ -81,7 +78,7 @@ class test_merge_dicts(unittest.TestCase):
         self.assertTrue(output_dict == input_dict)
 
     def test_unequal_types(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_unequal_types()
 
     def _test_unequal_types(self):
@@ -95,7 +92,7 @@ class test_merge_dicts(unittest.TestCase):
         self.assertRaises(ValueError, merge_dicts, dict_1, dict_2)
 
     def test_bools(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_bools()
 
     def _test_bools(self):
@@ -127,7 +124,7 @@ class test_merge_dicts(unittest.TestCase):
         self.assertEqual(output_dict["int"], 3)
 
     def test_floats(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_floats()
 
     def _test_floats(self):
@@ -143,7 +140,7 @@ class test_merge_dicts(unittest.TestCase):
         self.assertEqual(output_dict["float"], 9.1)
 
     def test_lists(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_lists()
 
     def _test_lists(self):
@@ -177,7 +174,7 @@ class test_merge_dicts(unittest.TestCase):
         )
 
     def test_unsupported(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_unsupported()
 
     def _test_unsupported(self):
@@ -198,7 +195,7 @@ class test_setopts(unittest.TestCase):
     """
 
     def test_setopts(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_setopts()
 
     def _test_setopts(self):
@@ -243,7 +240,7 @@ class test_inspect_dict(unittest.TestCase):
     """
 
     def test_compare_dict(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_compare_dict()
 
     def _test_compare_dict(self):
@@ -269,7 +266,7 @@ class test_inspect_dict(unittest.TestCase):
         self.assertTrue(compare_dict == output_dict)
 
     def test_compare_dict_with_print(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_compare_dict_with_print()
 
     def _test_compare_dict_with_print(self):
@@ -293,7 +290,7 @@ class test_custom_sort_dict(unittest.TestCase):
     """
 
     def test_custom_sort_dict(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_custom_sort_dict()
 
     def _test_custom_sort_dict(self):
@@ -320,7 +317,7 @@ class test_filter_dict(unittest.TestCase):
     """
 
     def test_filter_dict(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_filter_dict()
 
     def _test_filter_dict(self):
@@ -343,7 +340,7 @@ class test_filter_dict_through_values(unittest.TestCase):
     """
 
     def test_filter_dict_through_values(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_filter_dict_through_values()
 
     def _test_filter_dict_through_values(self):
@@ -366,7 +363,7 @@ class test_prepare_dict(unittest.TestCase):
     """
 
     def test_prepare_dict(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_prepare_dict()
 
     def _test_prepare_dict(self):
@@ -393,7 +390,7 @@ class test_normalize_dict(unittest.TestCase):
     """
 
     def test_normalize_dict(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_normalize_dict()
 
     def _test_normalize_dict(self):
@@ -414,7 +411,7 @@ class test_multiply_values_dict(unittest.TestCase):
     """
 
     def test_multiply_values_dict(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_multiply_values_dict()
 
     def _test_multiply_values_dict(self):
@@ -437,7 +434,7 @@ class test_count_keys_recursive(unittest.TestCase):
     """
 
     def test_count_keys_recursive(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_count_keys_recursive()
 
     def _test_count_keys_recursive(self):
@@ -459,7 +456,7 @@ class test_keys_to_floats(unittest.TestCase):
     """
 
     def test_keys_to_floats(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_keys_to_floats()
 
     def _test_keys_to_floats(self):
@@ -481,7 +478,7 @@ class test_recursive_change_key_to_float(unittest.TestCase):
     """
 
     def test_recursive_change_key_to_float(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_recursive_change_key_to_float()
 
     def _test_recursive_change_key_to_float(self):
@@ -505,7 +502,7 @@ class test_recursive_change_key_to_string(unittest.TestCase):
     """
 
     def test_recursive_change_key_to_string(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_recursive_change_key_to_string()
 
     def _test_recursive_change_key_to_string(self):
@@ -536,7 +533,7 @@ class test_multiply_float_values(unittest.TestCase):
     """
 
     def test_multiply_float_values(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_multiply_float_values()
 
     def _test_multiply_float_values(self):
@@ -563,7 +560,7 @@ class test_subtract_dicts(unittest.TestCase):
     """
 
     def test_empty(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_empty()
 
     def _test_empty(self):
@@ -581,7 +578,7 @@ class test_subtract_dicts(unittest.TestCase):
         self.assertTrue(output_dict == input_dict)
 
     def test_unequal_types(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_unequal_types()
 
     def _test_unequal_types(self):
@@ -611,7 +608,7 @@ class test_subtract_dicts(unittest.TestCase):
         self.assertEqual(output_dict["int"], 1)
 
     def test_floats(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_floats()
 
     def _test_floats(self):
@@ -627,7 +624,7 @@ class test_subtract_dicts(unittest.TestCase):
         self.assertAlmostEqual(output_dict["float"], -0.1, 2)
 
     def test_zero_result(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_zero_result()
 
     def _test_zero_result(self):
@@ -643,7 +640,7 @@ class test_subtract_dicts(unittest.TestCase):
         self.assertFalse(output_dict)
 
     def test_unsupported(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_unsupported()
 
     def _test_unsupported(self):
@@ -695,7 +692,7 @@ class test_update_dicts(unittest.TestCase):
         self.assertEqual(output_dict["dict"], {"a": 2, "b": 1, "c": 2})
 
     def test_unsupported(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_unsupported()
 
     def _test_unsupported(self):
@@ -715,7 +712,7 @@ class test__nested_get(unittest.TestCase):
     """
 
     def test__nested_get(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test__nested_get()
 
     def _test__nested_get(self):
@@ -738,7 +735,7 @@ class test__nested_set(unittest.TestCase):
     """
 
     def test__nested_set(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test__nested_set()
 
     def _test__nested_set(self):
