@@ -23,34 +23,34 @@ TODO: Capturing
 TODO: call_binary_c_config
 """
 
-import os
-import unittest
-import tempfile
-
 import json
+import os
+import tempfile
+import unittest
+
 import h5py
 
 from binarycpython.utils.custom_logging_functions import binary_c_log_code
-from binarycpython.utils.run_system_wrapper import run_system
 from binarycpython.utils.functions import (
-    verbose_print,
-    temp_dir,
     Capturing,
-    remove_file,
-    create_hdf5,
-    output_lines,
-    example_parse_output,
-    get_defaults,
-    get_arg_keys,
+    bin_data,
     create_arg_string,
+    create_hdf5,
+    example_parse_output,
+    get_arg_keys,
+    get_defaults,
     get_help,
     get_help_all,
     get_help_super,
-    make_build_text,
-    write_binary_c_parameter_descriptions_to_rst_file,
     get_username,
-    bin_data,
+    make_build_text,
+    output_lines,
+    remove_file,
+    temp_dir,
+    verbose_print,
+    write_binary_c_parameter_descriptions_to_rst_file,
 )
+from binarycpython.utils.run_system_wrapper import run_system
 
 TMP_DIR = temp_dir("tests", "test_functions")
 
@@ -61,7 +61,7 @@ class test_verbose_print(unittest.TestCase):
     """
 
     def test_print(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_print()
 
     def _test_print(self):
@@ -71,7 +71,7 @@ class test_verbose_print(unittest.TestCase):
         verbose_print("test1", 1, 0)
 
     def test_not_print(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_not_print()
 
     def _test_not_print(self):
@@ -88,7 +88,7 @@ class test_temp_dir(unittest.TestCase):
     """
 
     def test_create_temp_dir(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_create_temp_dir()
 
     def _test_create_temp_dir(self):
@@ -103,7 +103,6 @@ class test_temp_dir(unittest.TestCase):
 
         # Get username
         username = get_username()
-        dirname = "binary_c_python-{}".format(username)
 
         #
         self.assertTrue(
@@ -122,7 +121,7 @@ class test_remove_file(unittest.TestCase):
     """
 
     def test_remove_file(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_remove_file()
 
     def _test_remove_file(self):
@@ -136,7 +135,7 @@ class test_remove_file(unittest.TestCase):
         remove_file(os.path.join(TMP_DIR, "test_remove_file_file.txt"))
 
     def test_remove_nonexisting_file(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_remove_nonexisting_file()
 
     def _test_remove_nonexisting_file(self):
@@ -155,7 +154,7 @@ class test_create_hdf5(unittest.TestCase):
     """
 
     def test_1(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_1()
 
     def _test_1(self):
@@ -192,7 +191,7 @@ class test_output_lines(unittest.TestCase):
     """
 
     def test_1(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_1()
 
     def _test_1(self):
@@ -215,7 +214,7 @@ class test_example_parse_output(unittest.TestCase):
     """
 
     def test_normal_output(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_normal_output()
 
     def _test_normal_output(self):
@@ -248,7 +247,7 @@ class test_example_parse_output(unittest.TestCase):
         self.assertTrue(len(parsed_output["time"]) > 0)
 
     def test_mismatch_output(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_mismatch_output()
 
     def _test_mismatch_output(self):
@@ -283,7 +282,7 @@ class test_get_defaults(unittest.TestCase):
     """
 
     def test_no_filter(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_no_filter()
 
     def _test_no_filter(self):
@@ -300,10 +299,10 @@ class test_get_defaults(unittest.TestCase):
         self.assertIn("use_fixed_timestep_%d", output_1.keys())
 
     def test_filter(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_filter()
 
-    def test_filter(self):
+    def _test_filter(self):
         """
         Test checking filtering works correctly
         """
@@ -324,7 +323,7 @@ class test_get_arg_keys(unittest.TestCase):
     """
 
     def test_1(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_1()
 
     def _test_1(self):
@@ -347,7 +346,7 @@ class test_create_arg_string(unittest.TestCase):
     """
 
     def test_default(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_default()
 
     def _test_default(self):
@@ -360,7 +359,7 @@ class test_create_arg_string(unittest.TestCase):
         self.assertEqual(argstring, "separation 40000 M_1 10")
 
     def test_sort(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_sort()
 
     def _test_sort(self):
@@ -373,7 +372,7 @@ class test_create_arg_string(unittest.TestCase):
         self.assertEqual(argstring, "M_1 10 separation 40000")
 
     def test_filtered(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_filtered()
 
     def _test_filtered(self):
@@ -392,7 +391,7 @@ class test_get_help(unittest.TestCase):
     """
 
     def test_input_normal(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_input_normal()
 
     def _test_input_normal(self):
@@ -407,7 +406,7 @@ class test_get_help(unittest.TestCase):
         )
 
     def test_no_input(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_no_input()
 
     def _test_no_input(self):
@@ -419,7 +418,7 @@ class test_get_help(unittest.TestCase):
         self.assertIsNone(output)
 
     def test_wrong_input(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_wrong_input()
 
     def _test_wrong_input(self):
@@ -437,7 +436,7 @@ class test_get_help_all(unittest.TestCase):
     """
 
     def test_all_output(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_all_output()
 
     def _test_all_output(self):
@@ -467,7 +466,7 @@ class test_get_help_super(unittest.TestCase):
     """
 
     def test_all_output(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_all_output()
 
     def _test_all_output(self):
@@ -497,7 +496,7 @@ class test_make_build_text(unittest.TestCase):
     """
 
     def test_output(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_output()
 
     def _test_output(self):
@@ -527,7 +526,7 @@ class test_write_binary_c_parameter_descriptions_to_rst_file(unittest.TestCase):
     """
 
     def test_bad_outputname(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_bad_outputname()
 
     def _test_bad_outputname(self):
@@ -544,7 +543,7 @@ class test_write_binary_c_parameter_descriptions_to_rst_file(unittest.TestCase):
         )
 
     def test_checkfile(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_checkfile()
 
     def _test_checkfile(self):
@@ -556,7 +555,7 @@ class test_write_binary_c_parameter_descriptions_to_rst_file(unittest.TestCase):
             TMP_DIR,
             "test_write_binary_c_parameter_descriptions_to_rst_file_test_1.rst",
         )
-        output_1 = write_binary_c_parameter_descriptions_to_rst_file(output_name)
+        _ = write_binary_c_parameter_descriptions_to_rst_file(output_name)
         self.assertTrue(os.path.isfile(output_name))
 
 
