@@ -23,20 +23,18 @@ TODO: _check_binary_c_error
 TODO: Before running the non-unit tests to cover functions like evolve, we need to run the unit tests
 """
 
-import os
-import sys
-import json
 import gzip
+import json
+import os
 import shutil
+import sys
 import unittest
+
 import numpy as np
 
-from binarycpython.utils.functions import temp_dir, Capturing, remove_file, bin_data
-from binarycpython.utils.dicts import (
-    merge_dicts,
-)
-
-from binarycpython.utils.grid import Population
+from binarycpython.utils.dicts import merge_dicts
+from binarycpython.utils.functions import Capturing, bin_data, remove_file, temp_dir
+from binarycpython.utils.population_class import Population
 
 TMP_DIR = temp_dir("tests", "test_grid")
 shutil.rmtree(TMP_DIR)
@@ -45,7 +43,9 @@ os.makedirs(TMP_DIR, exist_ok=True)
 TEST_VERBOSITY = 1
 
 
-def parse_function_test_grid_evolve_2_threads_with_custom_logging(self, output): # pragma: no cover
+def parse_function_test_grid_evolve_2_threads_with_custom_logging(
+    self, output
+):  # pragma: no cover
     """
     Simple parse function that directly appends all the output to a file
     """
@@ -72,13 +72,11 @@ def parse_function_test_grid_evolve_2_threads_with_custom_logging(self, output):
             first_f.write(output + "\n")
 
 
-def parse_function_adding_results(self, output): # pragma: no cover
+def parse_function_adding_results(self, output):  # pragma: no cover
     """
     Example parse function
     """
 
-    seperator = " "
-
     parameters = ["time", "mass", "zams_mass", "probability", "stellar_type"]
 
     self.grid_results["example"]["count"] += 1
@@ -124,7 +122,7 @@ class test__setup(unittest.TestCase):
         self.assertTrue("metallicity" in test_pop.defaults)
         self.assertNotIn("help_all", test_pop.cleaned_up_defaults)
         self.assertEqual(test_pop.bse_options, {})
-        self.assertEqual(test_pop.custom_options, {})
+        self.assertEqual(test_pop.custom_options, {"save_snapshot": False})
         self.assertEqual(test_pop.argline_dict, {})
         self.assertEqual(test_pop.persistent_data_memory_dict, {})
         self.assertTrue(test_pop.grid_options["parse_function"] is None)
@@ -134,6 +132,8 @@ class test__setup(unittest.TestCase):
 class test_set(unittest.TestCase):
     """
     Unittests for _setup function
+
+    TODO: split into 4 sub-tests
     """
 
     def test_set(self):
@@ -145,26 +145,31 @@ class test_set(unittest.TestCase):
         Unittests for function set
         """
 
-        test_pop = Population(tmp_dir=TMP_DIR)
-        test_pop.set(num_cores=2, verbosity=TEST_VERBOSITY)
-        test_pop.set(M_1=10)
-        test_pop.set(data_dir="/tmp/binary_c_python")
-        test_pop.set(ensemble_filter_SUPERNOVAE=1, ensemble_dt=1000)
+        #
+        test_pop = Population(tmp_dir=TMP_DIR, verbosity=TEST_VERBOSITY)
 
+        # custom options test
+        test_pop.set(data_dir="/tmp/binary_c_python")
         self.assertIn("data_dir", test_pop.custom_options)
         self.assertEqual(test_pop.custom_options["data_dir"], "/tmp/binary_c_python")
 
-        #
+        # BSE options test
+        test_pop.set(M_1=10)
         self.assertTrue(test_pop.bse_options["M_1"] == 10)
+
+        # BSE options test special argument
+        test_pop.set(ensemble_filter_SUPERNOVAE=1, ensemble_dt=1000)
         self.assertTrue(test_pop.bse_options["ensemble_filter_SUPERNOVAE"] == 1)
 
-        #
+        # test grid options
+        test_pop.set(num_cores=2)
         self.assertTrue(test_pop.grid_options["num_cores"] == 2)
 
 
 class test_cmdline(unittest.TestCase):
     """
     Unittests for cmdline function
+    TODO: this has to be fixed. See parse_cmdline function
     """
 
     def test_cmdline(self):
@@ -198,8 +203,14 @@ class test_cmdline(unittest.TestCase):
         self.assertTrue(isinstance(test_pop.bse_options["metallicity"], str))
         self.assertTrue(test_pop.bse_options["metallicity"] == "0.0002")
 
-        # Amt cores
-        self.assertTrue(isinstance(test_pop.grid_options["num_cores"], int))
+        # Number of cores
+        print(test_pop.grid_options["num_cores"])
+        print(type(test_pop.grid_options["num_cores"]))
+        self.assertTrue(
+            isinstance(test_pop.grid_options["num_cores"], int)
+            or isinstance(test_pop.grid_options["num_cores"], dict)
+            or isinstance(test_pop.grid_options["num_cores"], str)
+        )
         self.assertTrue(test_pop.grid_options["num_cores"] == 2)
 
         # datadir
@@ -601,7 +612,7 @@ class test_resultdict(unittest.TestCase):
         resolution = {"M_1": 10}
 
         # Mass
-        example_pop.add_grid_variable(
+        example_pop.add_sampling_variable(
             name="lnm1",
             longname="Primary mass",
             valuerange=[2, 150],
@@ -613,10 +624,11 @@ class test_resultdict(unittest.TestCase):
             dphasevol="dlnm1",
             parameter_name="M_1",
             condition="",  # Impose a condition on this grid variable. Mostly for a check for yourself
+            gridtype="left",
         )
 
         ## Executing a population
-        ## This uses the values generated by the grid_variables
+        ## This uses the values generated by the sampling_variables
         analytics = example_pop.evolve()
 
         #
@@ -686,7 +698,7 @@ class test_grid_evolve(unittest.TestCase):
 
         resolution = {"M_1": 10}
 
-        test_pop_evolve_1_thread.add_grid_variable(
+        test_pop_evolve_1_thread.add_sampling_variable(
             name="lnm1",
             longname="Primary mass",
             valuerange=[1, 100],
@@ -724,7 +736,7 @@ class test_grid_evolve(unittest.TestCase):
 
         resolution = {"M_1": 10}
 
-        test_pop.add_grid_variable(
+        test_pop.add_sampling_variable(
             name="lnm1",
             longname="Primary mass",
             valuerange=[1, 100],
@@ -771,9 +783,9 @@ class test_grid_evolve(unittest.TestCase):
             parse_function=parse_function_test_grid_evolve_2_threads_with_custom_logging,
         )
         test_pop.set(ensemble=0)
-        resolution = {"M_1": 2}
+        resolution = {"M_1": 20}
 
-        test_pop.add_grid_variable(
+        test_pop.add_sampling_variable(
             name="lnm1",
             longname="Primary mass",
             valuerange=[1, 100],
@@ -843,7 +855,7 @@ Printf("TEST_CUSTOM_LOGGING_1 %30.12e %g %g %g %g\\n",
         test_pop.set(C_logging_code=CUSTOM_LOGGING_STRING_WITH_EXIT)
 
         resolution = {"M_1": 10}
-        test_pop.add_grid_variable(
+        test_pop.add_sampling_variable(
             name="lnm1",
             longname="Primary mass",
             valuerange=[1, 100],
@@ -880,7 +892,7 @@ Printf("TEST_CUSTOM_LOGGING_1 %30.12e %g %g %g %g\\n",
 
         resolution = {"M_1": 10, "q": 2}
 
-        test_pop.add_grid_variable(
+        test_pop.add_sampling_variable(
             name="lnm1",
             longname="Primary mass",
             valuerange=[1, 100],
@@ -894,7 +906,7 @@ Printf("TEST_CUSTOM_LOGGING_1 %30.12e %g %g %g %g\\n",
             condition="",  # Impose a condition on this grid variable. Mostly for a check for yourself
         )
 
-        test_pop.add_grid_variable(
+        test_pop.add_sampling_variable(
             name="q",
             longname="Mass ratio",
             valuerange=["0.1/M_1", 1],
@@ -914,11 +926,11 @@ Printf("TEST_CUSTOM_LOGGING_1 %30.12e %g %g %g %g\\n",
 
         # self.assertRaises(ValueError, test_pop.evolve)
 
-    def test_grid_evolve_no_grid_variables(self):
+    def test_grid_evolve_no_sampling_variables(self):
         with Capturing() as _:
-            self._test_grid_evolve_no_grid_variables()
+            self._test_grid_evolve_no_sampling_variables()
 
-    def _test_grid_evolve_no_grid_variables(self):
+    def _test_grid_evolve_no_sampling_variables(self):
         """
         Unittests to see if errors are raised if there are no grid variables
         """
@@ -927,8 +939,6 @@ Printf("TEST_CUSTOM_LOGGING_1 %30.12e %g %g %g %g\\n",
         test_pop.set(
             num_cores=1, M_2=1, orbital_period=100000, verbosity=TEST_VERBOSITY
         )
-
-        resolution = {"M_1": 10}
         self.assertRaises(ValueError, test_pop.evolve)
 
     def test_grid_evolve_2_threads_with_ensemble_direct_output(self):
@@ -962,7 +972,7 @@ Printf("TEST_CUSTOM_LOGGING_1 %30.12e %g %g %g %g\\n",
 
         resolution = {"M_1": 10}
 
-        test_pop.add_grid_variable(
+        test_pop.add_sampling_variable(
             name="lnm1",
             longname="Primary mass",
             valuerange=[1, 100],
@@ -1010,7 +1020,6 @@ Printf("TEST_CUSTOM_LOGGING_1 %30.12e %g %g %g %g\\n",
         Unittests to see if multiple threads correclty combine the ensemble data and store them in the grid
         """
 
-        data_dir_value = TMP_DIR
         num_cores_value = 2
 
         test_pop = Population(tmp_dir=TMP_DIR)
@@ -1032,7 +1041,7 @@ Printf("TEST_CUSTOM_LOGGING_1 %30.12e %g %g %g %g\\n",
 
         resolution = {"M_1": 10}
 
-        test_pop.add_grid_variable(
+        test_pop.add_sampling_variable(
             name="lnm1",
             longname="Primary mass",
             valuerange=[1, 100],
@@ -1046,7 +1055,7 @@ Printf("TEST_CUSTOM_LOGGING_1 %30.12e %g %g %g %g\\n",
             condition="",  # Impose a condition on this grid variable. Mostly for a check for yourself
         )
 
-        analytics = test_pop.evolve()
+        _ = test_pop.evolve()
 
         self.assertTrue(isinstance(test_pop.grid_ensemble_results["ensemble"], dict))
         self.assertNotEqual(test_pop.grid_ensemble_results["ensemble"], {})
@@ -1088,7 +1097,7 @@ Printf("TEST_CUSTOM_LOGGING_1 %30.12e %g %g %g %g\\n",
 
         resolution = {"M_1": 10}
 
-        test_pop_1.add_grid_variable(
+        test_pop_1.add_sampling_variable(
             name="lnm1",
             longname="Primary mass",
             valuerange=[1, 100],
@@ -1102,7 +1111,7 @@ Printf("TEST_CUSTOM_LOGGING_1 %30.12e %g %g %g %g\\n",
             condition="",  # Impose a condition on this grid variable. Mostly for a check for yourself
         )
 
-        analytics_1 = test_pop_1.evolve()
+        _ = test_pop_1.evolve()
         ensemble_output_1 = test_pop_1.grid_ensemble_results
 
         # second
@@ -1125,7 +1134,7 @@ Printf("TEST_CUSTOM_LOGGING_1 %30.12e %g %g %g %g\\n",
 
         resolution = {"M_1": 10}
 
-        test_pop_2.add_grid_variable(
+        test_pop_2.add_sampling_variable(
             name="lnm1",
             longname="Primary mass",
             valuerange=[1, 100],
