@@ -23,8 +23,9 @@ TODO: HPC_queue_stats
 import os
 import shutil
 import unittest
+
 from binarycpython.utils.functions import Capturing, temp_dir
-from binarycpython.utils.grid import Population
+from binarycpython.utils.population_class import Population
 
 TMP_DIR = temp_dir("tests", "test_HPC")
 shutil.rmtree(TMP_DIR)
@@ -37,7 +38,7 @@ class test_HPC_njobs(unittest.TestCase):
     """
 
     def test_condor(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_condor()
 
     def _test_condor(self):
@@ -54,7 +55,7 @@ class test_HPC_njobs(unittest.TestCase):
         self.assertEqual(result_condor, 10)
 
     def test_slurm(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_slurm()
 
     def _test_slurm(self):
@@ -71,7 +72,7 @@ class test_HPC_njobs(unittest.TestCase):
         self.assertEqual(result_slurm, 11)
 
     def test_none(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_none()
 
     def _test_none(self):
@@ -89,7 +90,7 @@ class test_HPC_job(unittest.TestCase):
     """
 
     def test_HPC_job(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_HPC_job()
 
     def _test_HPC_job(self):
@@ -109,7 +110,7 @@ class test_HPC_job_type(unittest.TestCase):
     """
 
     def test_condor(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_condor()
 
     def _test_condor(self):
@@ -124,7 +125,7 @@ class test_HPC_job_type(unittest.TestCase):
         self.assertEqual(result_condor, "condor")
 
     def test_slurm(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_slurm()
 
     def _test_slurm(self):
@@ -139,7 +140,7 @@ class test_HPC_job_type(unittest.TestCase):
         self.assertEqual(result_slurm, "slurm")
 
     def test_none(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_none()
 
     def _test_none(self):
@@ -158,7 +159,7 @@ class test_HPC_jobID(unittest.TestCase):
     """
 
     def test_condor(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_condor()
 
     def _test_condor(self):
@@ -177,7 +178,7 @@ class test_HPC_jobID(unittest.TestCase):
         )
 
     def test_slurm(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_slurm()
 
     def _test_slurm(self):
@@ -196,7 +197,7 @@ class test_HPC_jobID(unittest.TestCase):
         )
 
     def test_none(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_none()
 
     def _test_none(self):
@@ -215,7 +216,7 @@ class test_HPC_jobID_tuple(unittest.TestCase):
     """
 
     def test_condor(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_condor()
 
     def _test_condor(self):
@@ -231,7 +232,7 @@ class test_HPC_jobID_tuple(unittest.TestCase):
         self.assertEqual(condor_pop.HPC_jobID_tuple(), ("2", "3"))
 
     def test_slurm(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_slurm()
 
     def _test_slurm(self):
@@ -247,7 +248,7 @@ class test_HPC_jobID_tuple(unittest.TestCase):
         self.assertEqual(slurm_pop.HPC_jobID_tuple(), ("4", "5"))
 
     def test_none(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_none()
 
     def _test_none(self):
@@ -265,7 +266,7 @@ class test_HPC_dirs(unittest.TestCase):
     """
 
     def test_condor(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_condor()
 
     def _test_condor(self):
@@ -278,7 +279,7 @@ class test_HPC_dirs(unittest.TestCase):
         self.assertEqual(condor_pop.HPC_dirs(), ["condor_dir"])
 
     def test_slurm(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_slurm()
 
     def _test_slurm(self):
@@ -291,7 +292,7 @@ class test_HPC_dirs(unittest.TestCase):
         self.assertEqual(slurm_pop.HPC_dirs(), ["slurm_dir"])
 
     def test_none(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_none()
 
     def _test_none(self):
@@ -309,7 +310,7 @@ class test_HPC_id_filename(unittest.TestCase):
     """
 
     def test_condor(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_condor()
 
     def _test_condor(self):
@@ -322,7 +323,7 @@ class test_HPC_id_filename(unittest.TestCase):
         self.assertEqual(condor_pop.HPC_id_filename(), "ClusterID")
 
     def test_slurm(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_slurm()
 
     def _test_slurm(self):
@@ -335,7 +336,7 @@ class test_HPC_id_filename(unittest.TestCase):
         self.assertEqual(slurm_pop.HPC_id_filename(), "jobid")
 
     def test_none(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_none()
 
     def _test_none(self):
@@ -353,7 +354,7 @@ class test_HPC_check_requirements(unittest.TestCase):
     """
 
     def test_condor(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_condor()
 
     def _test_condor(self):
@@ -380,7 +381,7 @@ class test_HPC_check_requirements(unittest.TestCase):
         self.assertTrue(len(result_2[1]) == 0)
 
     def test_slurm(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_slurm()
 
     def _test_slurm(self):
@@ -403,7 +404,7 @@ class test_HPC_check_requirements(unittest.TestCase):
         self.assertTrue(len(result_2[1]) == 0)
 
     def test_none(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_none()
 
     def _test_none(self):
@@ -423,7 +424,7 @@ class test_HPC_set_status(unittest.TestCase):
     """
 
     def test_condor(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_condor()
 
     def _test_condor(self):
@@ -474,7 +475,7 @@ class test_HPC_set_status(unittest.TestCase):
         self.assertTrue(content_file == "test_set_condor_status")
 
     def test_slurm(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_slurm()
 
     def _test_slurm(self):
@@ -527,7 +528,7 @@ class test_HPC_get_status(unittest.TestCase):
     """
 
     def test_condor(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_condor()
 
     def _test_condor(self):
@@ -557,7 +558,7 @@ class test_HPC_get_status(unittest.TestCase):
         self.assertEqual(status, "test_get_condor_status")
 
     def test_slurm(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_slurm()
 
     def _test_slurm(self):
@@ -592,7 +593,7 @@ class test_HPC_job_task(unittest.TestCase):
     """
 
     def test_condor(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_condor()
 
     def _test_condor(self):
@@ -610,9 +611,8 @@ class test_HPC_job_task(unittest.TestCase):
         job_task = condor_pop.HPC_job_task()
         self.assertEqual(job_task, 1)
 
-
     def test_slurm(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_slurm()
 
     def _test_slurm(self):
@@ -637,7 +637,7 @@ class test_HPC_dir(unittest.TestCase):
     """
 
     def test_condor(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_condor()
 
     def _test_condor(self):
@@ -654,9 +654,8 @@ class test_HPC_dir(unittest.TestCase):
         #
         self.assertEqual(condor_pop.HPC_dir(), os.path.join(TMP_DIR, "condor"))
 
-
     def test_slurm(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_slurm()
 
     def _test_slurm(self):
@@ -674,7 +673,7 @@ class test_HPC_dir(unittest.TestCase):
         self.assertEqual(slurm_pop.HPC_dir(), os.path.join(TMP_DIR, "slurm"))
 
     def test_none(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_slurm()
 
     def _test_none(self):
@@ -694,7 +693,7 @@ class test_HPC_id_from_dir(unittest.TestCase):
     """
 
     def test_condor(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_condor()
 
     def _test_condor(self):
@@ -714,7 +713,7 @@ class test_HPC_id_from_dir(unittest.TestCase):
         self.assertEqual(id_from_dir.strip(), str(2))
 
     def test_slurm(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_slurm()
 
     def _test_slurm(self):
