@@ -1,5 +1,5 @@
 """
-Module containing the unittests for the distribution functions. 
+Module containing the unittests for the distribution functions.
 
 TODO: powerlaw_constant_nocache
 TODO: powerlaw_constant
@@ -27,19 +27,19 @@ TODO: Moe_di_Stefano_2017_pdf
 """
 
 import unittest
+
 import numpy as np
 
-from binarycpython.utils.useful_funcs import calc_sep_from_period
 from binarycpython.utils.functions import Capturing, temp_dir
-
-from binarycpython.utils.grid import Population
+from binarycpython.utils.population_class import Population
+from binarycpython.utils.useful_funcs import calc_sep_from_period
 
 TMP_DIR = temp_dir("tests", "test_distributions")
 
 MASS_LIST = [0.1, 0.2, 1, 10, 15, 50]
 LOGPER_LIST = [-2, -0.5, 1.6, 2.5, 5.3, 10]
 Q_LIST = [0.01, 0.2, 0.4, 0.652, 0.823, 1]
-PER_LIST = [10 ** logper for logper in LOGPER_LIST]
+PER_LIST = [10**logper for logper in LOGPER_LIST]
 TOLERANCE = 1e-5
 
 
@@ -49,7 +49,7 @@ class test_flat(unittest.TestCase):
     """
 
     def test_flat(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_flat()
 
     def _test_flat(self):
@@ -57,7 +57,7 @@ class test_flat(unittest.TestCase):
         Unittest for the function flat
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         output_1 = distribution_functions_pop.flat()
 
@@ -71,7 +71,7 @@ class test_number(unittest.TestCase):
     """
 
     def test_number(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_number()
 
     def _test_number(self):
@@ -79,7 +79,7 @@ class test_number(unittest.TestCase):
         Unittest for function number
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         input_1 = 1.0
         output_1 = distribution_functions_pop.number(input_1)
@@ -93,7 +93,7 @@ class test_const_distribution(unittest.TestCase):
     """
 
     def test_const_distribution(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_const_distribution()
 
     def _test_const_distribution(self):
@@ -101,7 +101,7 @@ class test_const_distribution(unittest.TestCase):
         Unittest for function const
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         output_1 = distribution_functions_pop.const_distribution(
             min_bound=0, max_bound=2
@@ -124,7 +124,7 @@ class test_powerlaw(unittest.TestCase):
     """
 
     def test_powerlaw(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_powerlaw()
 
     def _test_powerlaw(self):
@@ -132,7 +132,7 @@ class test_powerlaw(unittest.TestCase):
         unittest for the powerlaw test
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         perl_results = [
             0,
@@ -156,7 +156,9 @@ class test_powerlaw(unittest.TestCase):
             msg = "Error: Value perl: {} Value python: {} for mass, per: {}".format(
                 perl_results[i], python_results[i], str(input_lists[i])
             )
-            self.assertLess(np.abs(python_results[i] - perl_results[i]), TOLERANCE)
+            self.assertLess(
+                np.abs(python_results[i] - perl_results[i]), TOLERANCE, msg=msg
+            )
 
         # extra test for k = -1
         self.assertRaises(
@@ -170,7 +172,7 @@ class test_three_part_power_law(unittest.TestCase):
     """
 
     def test_three_part_power_law(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_three_part_power_law()
 
     def _test_three_part_power_law(self):
@@ -178,7 +180,7 @@ class test_three_part_power_law(unittest.TestCase):
         unittest for three_part_power_law
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         perl_results = [
             10.0001044752901,
@@ -225,7 +227,7 @@ class test_Kroupa2001(unittest.TestCase):
     """
 
     def test_Kroupa2001(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_Kroupa2001()
 
     def _test_Kroupa2001(self):
@@ -233,7 +235,7 @@ class test_Kroupa2001(unittest.TestCase):
         unittest for three_part_power_law
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         perl_results = [
             0,  # perl value is actually 5.71196495365248
@@ -274,7 +276,7 @@ class test_ktg93(unittest.TestCase):
     """
 
     def test_ktg93(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_ktg93()
 
     def _test_ktg93(self):
@@ -282,7 +284,7 @@ class test_ktg93(unittest.TestCase):
         unittest for three_part_power_law
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         perl_results = [
             0,  # perl value is actually 5.79767807698379 but that is not correct
@@ -323,7 +325,7 @@ class test_imf_tinsley1980(unittest.TestCase):
     """
 
     def test_imf_tinsley1980(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_imf_tinsley1980()
 
     def _test_imf_tinsley1980(self):
@@ -331,7 +333,7 @@ class test_imf_tinsley1980(unittest.TestCase):
         Unittest for function imf_tinsley1980
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         m = 1.2
         self.assertEqual(
@@ -348,7 +350,7 @@ class test_imf_scalo1986(unittest.TestCase):
     """
 
     def test_imf_scalo1986(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_imf_scalo1986()
 
     def _test_imf_scalo1986(self):
@@ -356,7 +358,7 @@ class test_imf_scalo1986(unittest.TestCase):
         Unittest for function imf_scalo1986
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         m = 1.2
         self.assertEqual(
@@ -373,7 +375,7 @@ class test_imf_scalo1998(unittest.TestCase):
     """
 
     def test_imf_scalo1998(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_imf_scalo1998()
 
     def _test_imf_scalo1998(self):
@@ -381,7 +383,7 @@ class test_imf_scalo1998(unittest.TestCase):
         Unittest for function imf_scalo1986
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         m = 1.2
         self.assertEqual(
@@ -398,7 +400,7 @@ class test_imf_chabrier2003(unittest.TestCase):
     """
 
     def test_imf_chabrier2003(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_imf_chabrier2003()
 
     def _test_imf_chabrier2003(self):
@@ -406,7 +408,7 @@ class test_imf_chabrier2003(unittest.TestCase):
         Unittest for function imf_chabrier2003
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         input_1 = 0
         self.assertRaises(
@@ -444,7 +446,7 @@ class test_duquennoy1991(unittest.TestCase):
     """
 
     def test_duquennoy1991(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_duquennoy1991()
 
     def _test_duquennoy1991(self):
@@ -452,7 +454,7 @@ class test_duquennoy1991(unittest.TestCase):
         Unittest for function duquennoy1991
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         self.assertEqual(
             distribution_functions_pop.duquennoy1991(4.2),
@@ -466,7 +468,7 @@ class test_gaussian(unittest.TestCase):
     """
 
     def test_gaussian(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_gaussian()
 
     def _test_gaussian(self):
@@ -474,7 +476,7 @@ class test_gaussian(unittest.TestCase):
         unittest for three_part_power_law
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         perl_results = [
             0.00218800520299544,
@@ -515,7 +517,7 @@ class test_Arenou2010_binary_fraction(unittest.TestCase):
     """
 
     def test_Arenou2010_binary_fraction(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_Arenou2010_binary_fraction()
 
     def _test_Arenou2010_binary_fraction(self):
@@ -523,7 +525,7 @@ class test_Arenou2010_binary_fraction(unittest.TestCase):
         unittest for three_part_power_law
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         perl_results = [
             0.123079723518677,
@@ -558,7 +560,7 @@ class test_raghavan2010_binary_fraction(unittest.TestCase):
     """
 
     def test_raghavan2010_binary_fraction(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_raghavan2010_binary_fraction()
 
     def _test_raghavan2010_binary_fraction(self):
@@ -566,7 +568,7 @@ class test_raghavan2010_binary_fraction(unittest.TestCase):
         unittest for three_part_power_law
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         perl_results = [0.304872297931597, 0.334079955706623, 0.41024, 1, 1, 1]
         python_results = []
@@ -594,7 +596,7 @@ class test_Izzard2012_period_distribution(unittest.TestCase):
     """
 
     def test_Izzard2012_period_distribution(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_Izzard2012_period_distribution()
 
     def _test_Izzard2012_period_distribution(self):
@@ -602,7 +604,7 @@ class test_Izzard2012_period_distribution(unittest.TestCase):
         unittest for three_part_power_law
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         perl_results = [
             0,
@@ -669,7 +671,7 @@ class test_flatsections(unittest.TestCase):
     """
 
     def test_flatsections(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_flatsections()
 
     def _test_flatsections(self):
@@ -677,7 +679,7 @@ class test_flatsections(unittest.TestCase):
         unittest for flatsections
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         perl_results = [
             1.01010101010101,
@@ -714,7 +716,7 @@ class test_sana12(unittest.TestCase):
     """
 
     def test_sana12(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_sana12()
 
     def _test_sana12(self):
@@ -722,7 +724,7 @@ class test_sana12(unittest.TestCase):
         unittest for three_part_power_law
         """
 
-        distribution_functions_pop = Population()
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
         perl_results = [
             0.121764808010258,
@@ -951,8 +953,8 @@ class test_sana12(unittest.TestCase):
                     mass_2 = mass * q
 
                     sep = calc_sep_from_period(mass, mass_2, per)
-                    sep_min = calc_sep_from_period(mass, mass_2, 10 ** 0.15)
-                    sep_max = calc_sep_from_period(mass, mass_2, 10 ** 5.5)
+                    sep_min = calc_sep_from_period(mass, mass_2, 10**0.15)
+                    sep_max = calc_sep_from_period(mass, mass_2, 10**5.5)
 
                     input_lists.append([mass, mass_2, per])
 
@@ -972,5 +974,199 @@ class test_sana12(unittest.TestCase):
             )
 
 
+class test_get_max_multiplicity(unittest.TestCase):
+    """
+    Class for unit test of get_max_multiplicity
+    """
+
+    def test_get_max_multiplicity(self):
+        with Capturing() as _:
+            self._test_get_max_multiplicity()
+
+    def _test_get_max_multiplicity(self):
+        """
+        Unittest for the function get_max_multiplicity
+        """
+
+        #
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
+
+        # test with single number
+        max_multiplicity = distribution_functions_pop.get_max_multiplicity(
+            multiplicity_array=[0, 1, 0, 0]
+        )
+        self.assertEqual(max_multiplicity, 2)
+
+        # test with double number
+        max_multiplicity = distribution_functions_pop.get_max_multiplicity(
+            multiplicity_array=[0, 1, 0, 1]
+        )
+        self.assertEqual(max_multiplicity, 4)
+
+        # test with no number
+        max_multiplicity = distribution_functions_pop.get_max_multiplicity(
+            multiplicity_array=[0, 0, 0, 0]
+        )
+        self.assertEqual(max_multiplicity, 0)
+
+
+class test__get_multiplicity_dict(unittest.TestCase):
+    """
+    Class for unit test of _get_multiplicity_dict
+    """
+
+    def test__no_multiplicity_fraction_function(self):
+        with Capturing() as _:
+            self._test__no_multiplicity_fraction_function()
+
+    def _test__no_multiplicity_fraction_function(self):
+        """
+        Unittest for the function _get_multiplicity_dict without a set multiplicity_fraction_function
+        """
+
+        #
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
+
+        # test without a set multiplicity
+        self.assertRaises(
+            ValueError, distribution_functions_pop._get_multiplicity_dict, {"M_1": 1}
+        )
+
+        # test with a set multiplicity
+        multiplicity_dict = distribution_functions_pop._get_multiplicity_dict(
+            system_dict={"M_1": 1, "multiplicity": 2}
+        )
+        self.assertEqual(
+            multiplicity_dict,
+            {1: 0.0, 2: 1.0, 3: 0.0, 4: 0.0},
+        )
+
+    def test__unknown_multiplicity_fraction_function(self):
+        with Capturing() as _:
+            self._test__unknown_multiplicity_fraction_function()
+
+    def _test__unknown_multiplicity_fraction_function(self):
+        """
+        Unittest for the function _get_multiplicity_dict with an unknown multiplicity fraction function
+        """
+
+        #
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
+        distribution_functions_pop.set(multiplicity_fraction_function=-1)
+
+        # test without a set multiplicity
+        self.assertRaises(
+            ValueError, distribution_functions_pop._get_multiplicity_dict, {"M_1": 1}
+        )
+
+    def test__arenou2010_multiplicity_fraction_function(self):
+        with Capturing() as _:
+            self._test__arenou2010_multiplicity_fraction_function()
+
+    def _test__arenou2010_multiplicity_fraction_function(self):
+        """
+        Unittest for the function _get_multiplicity_dict with arenou2010 multiplicity fraction function
+        """
+
+        #
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
+        distribution_functions_pop.set(multiplicity_fraction_function="Arenou2010")
+        system_dict = {"M_1": 0.5}
+
+        #
+        arenou2010_binary_fraction = (
+            distribution_functions_pop.Arenou2010_binary_fraction(system_dict["M_1"])
+        )
+        multiplicity_dict = distribution_functions_pop._get_multiplicity_dict(
+            system_dict=system_dict
+        )
+        self.assertEqual(
+            multiplicity_dict,
+            {
+                1: 1 - arenou2010_binary_fraction,
+                2: arenou2010_binary_fraction,
+                3: 0.0,
+                4: 0.0,
+            },
+        )
+
+    def test__raghavan2010_multiplicity_fraction_function(self):
+        with Capturing() as _:
+            self._test__raghavan2010_multiplicity_fraction_function()
+
+    def _test__raghavan2010_multiplicity_fraction_function(self):
+        """
+        Unittest for the function _get_multiplicity_dict with raghavan2010 multiplicity fraction function
+        """
+
+        #
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
+        distribution_functions_pop.set(multiplicity_fraction_function="Raghavan2010")
+        system_dict = {"M_1": 0.5}
+
+        #
+        raghavan2010_binary_fraction = (
+            distribution_functions_pop.raghavan2010_binary_fraction(system_dict["M_1"])
+        )
+        multiplicity_dict = distribution_functions_pop._get_multiplicity_dict(
+            system_dict=system_dict
+        )
+        self.assertEqual(
+            multiplicity_dict,
+            {
+                1: 1 - raghavan2010_binary_fraction,
+                2: raghavan2010_binary_fraction,
+                3: 0.0,
+                4: 0.0,
+            },
+        )
+
+    def test__moe2017_multiplicity_fraction_function(self):
+        with Capturing() as _:
+            self._test__moe2017_multiplicity_fraction_function()
+
+    def _test__moe2017_multiplicity_fraction_function(self):
+        """
+        Unittest for the function _get_multiplicity_dict with moe2017 multiplicity fraction function
+        """
+
+        #
+        distribution_functions_pop = Population(tmp_dir=TMP_DIR)
+        distribution_functions_pop.set(multiplicity_fraction_function="Moe2017")
+        system_dict = {"M_1": 0.5}
+
+        # Test without moecache
+        global Moecache
+        Moecache = {}
+        _ = distribution_functions_pop._get_multiplicity_dict(system_dict)
+
+        # test directly with values for Moe function
+        distribution_functions_pop.grid_options["Moe2017_options"]["M_1"] = system_dict[
+            "M_1"
+        ]
+        multiplicity_fractions_moe = (
+            distribution_functions_pop.Moe_di_Stefano_2017_multiplicity_fractions(
+                distribution_functions_pop.grid_options["Moe2017_options"], 1
+            )
+        )
+
+        multiplicity_dict_moe = distribution_functions_pop._get_multiplicity_dict(
+            system_dict=system_dict
+        )
+        self.assertEqual(
+            multiplicity_dict_moe,
+            {
+                el + 1: multiplicity_fractions_moe[el]
+                for el in range(len(multiplicity_fractions_moe))
+            },
+        )
+
+        # Test without setting Moe2017 options
+        distribution_functions_pop.grid_options["Moe2017_options"] = None
+        self.assertRaises(
+            ValueError, distribution_functions_pop._get_multiplicity_dict, {"M_1": 1}
+        )
+
+
 if __name__ == "__main__":
     unittest.main()
