@@ -10,11 +10,20 @@ TODO: gaussian_zoom
 TODO: const_dt
 """
 
+import os
+import shutil
 import unittest
+
 import numpy as np
 
-from binarycpython.utils.spacing_functions import const
-from binarycpython.utils.functions import Capturing
+from binarycpython.utils.functions import Capturing, temp_dir
+from binarycpython.utils.population_class import Population
+
+TMP_DIR = temp_dir("tests", "test_spacing_functions")
+
+shutil.rmtree(TMP_DIR)
+os.makedirs(TMP_DIR, exist_ok=True)
+distribution_functions_pop = Population()
 
 
 class test_spacing_functions(unittest.TestCase):
@@ -23,7 +32,7 @@ class test_spacing_functions(unittest.TestCase):
     """
 
     def test_const(self):
-        with Capturing() as output:
+        with Capturing() as _:
             self._test_const()
 
     def _test_const(self):
@@ -31,10 +40,9 @@ class test_spacing_functions(unittest.TestCase):
         Unittest for function const
         """
 
-        const_return = const(1, 10, 10)
+        const_return = distribution_functions_pop.const_linear(1, 10, 10)
         self.assertTrue(
             (const_return == np.linspace(1, 10, 10 + 1)).all(),
-            msg="Output didn't contain SINGLE_STAR_LIFETIME",
         )
 
 
