@@ -1,33 +1,40 @@
 """
 Module containing functions to interact with binary_c's
 population ensemble using the binarycpython package
-
 """
 
-import sys
 import bz2
-import time
-import json
-from typing import Any
 import gc
 import gzip
 import inspect
+import json
+import sys
+import time
+from typing import Any
 
-from halo import Halo
 import msgpack
 import py_rinterpolate
-
 import simplejson
+from halo import Halo
 
 from binarycpython.utils.dicts import (
+    custom_sort_dict,
     keys_to_floats,
     recursive_change_key_to_float,
-    custom_sort_dict,
     recursive_change_key_to_string,
 )
 from binarycpython.utils.functions import verbose_print
 
 
+def new_grid_ensemble_results():
+    """
+    Function to return a new grid_ensemble_results dict: this should
+    be pre-filled by sub-dicts to prevent later errors.
+    """
+
+    return {"metadata": {}, "ensemble": {}}
+
+
 def ensemble_setting(ensemble, parameter_name):
     """
     Function to get the setting of parameter_name in the given ensemble, or return the default value.
@@ -115,7 +122,12 @@ def ensemble_file_type(filename):
 
 
 def load_ensemble(
-    filename, convert_float_keys=True, select_keys=None, timing=False, flush=False
+    filename,
+    convert_float_keys=True,
+    select_keys=None,
+    timing=False,
+    flush=False,
+    quiet=False,
 ):
     """
     Function to load an ensemeble file, even if it is compressed,
@@ -129,7 +141,8 @@ def load_ensemble(
     # open the file
 
     # load with some info to the terminal
-    print("Loading JSON...", flush=flush)
+    if not quiet:
+        print("Loading JSON...", flush=flush)
 
     # open the ensemble and get the file type
     file_object = open_ensemble(filename)
@@ -142,53 +155,72 @@ def load_ensemble(
         )
         sys.exit()
 
-    with Halo(text="Loading", interval=250, spinner="moon", color="yellow"):
+    if quiet:
         tstart = time.time()
-        _loaded = False
-
-        def _hook(obj):
-            """
-            Hook to load ensemble
-            """
-
-            nonlocal _loaded
-            if _loaded is False:
-                _loaded = True
-                print(
-                    "\nLoaded {} data, now putting in a dictionary".format(filetype),
-                    flush=True,
-                )
-            return obj
-
         if filetype == "JSON":
-            # orjson promises to be fast, but it doesn't seem to be
-            # and fails on "Infinity"... oops
-            # data = orjson.loads(file_object.read())
-
-            # simplejson is faster than standard json and "just works"
-            # on the big Moe set in 37s
-            data = simplejson.load(file_object, object_hook=_hook)
+            data = simplejson.load(file_object)
             file_object.close()
-
-            # standard json module
-            # on the big Moe set takes 42s
-            # data = json.load(file_object,
-            #                 object_hook=_hook)
         elif filetype == "msgpack":
-            data = msgpack.load(file_object, object_hook=_hook)
+            data = msgpack.load(file_object, object_hook=_hook)  # noqa: F821
             file_object.close()
-
         if timing:
             print(
                 "\n\nTook {} s to load the data\n\n".format(time.time() - tstart),
                 flush=True,
             )
+    else:
+        with Halo(text="Loading", interval=250, spinner="moon", color="yellow"):
+            tstart = time.time()
+            _loaded = False
+
+            def _hook(obj):
+                """
+                Hook to load ensemble
+                """
+
+                nonlocal _loaded
+                if not _loaded:
+                    _loaded = True
+                    print(
+                        "\nLoaded {} data, now putting in a dictionary".format(
+                            filetype
+                        ),
+                        flush=True,
+                    )
+                return obj
+
+            if filetype == "JSON":
+                # orjson promises to be fast, but it doesn't seem to be
+                # and fails on "Infinity"... oops
+                # data = orjson.loads(file_object.read())
+
+                # simplejson is faster than standard json and "just works"
+                # on the big Moe set in 37s
+                if not quiet:
+                    data = simplejson.load(file_object, object_hook=_hook)
+                else:
+                    data = simplejson.load(file_object)
+                file_object.close()
+
+                # standard json module
+                # on the big Moe set takes 42s
+                # data = json.load(file_object,
+                #                 object_hook=_hook)
+            elif filetype == "msgpack":
+                data = msgpack.load(file_object, object_hook=_hook)
+                file_object.close()
+
+            if timing:
+                print(
+                    "\n\nTook {} s to load the data\n\n".format(time.time() - tstart),
+                    flush=True,
+                )
 
     # strip non-selected keys, if a list is given in select_keys
     if select_keys:
         keys = list(data["ensemble"].keys())
         for key in keys:
-            if not key in select_keys:
+            if key not in select_keys:
                 del data["ensemble"][key]
 
     # perhaps convert floats?
@@ -294,9 +326,12 @@ def binaryc_json_serializer(obj: Any) -> Any:
             return string_version
         except:
             raise TypeError(
-                "Unserializable object {} of type {}. Attempted to convert to string but that failed.".format(obj, type(obj))
+                "Unserializable object {} of type {}. Attempted to convert to string but that failed.".format(
+                    obj, type(obj)
+                )
             )
 
+
 class BinarycDecoder(json.JSONDecoder):
     """
     Custom decoder to transform the numbers that are strings to actual floats
