@@ -8,25 +8,26 @@ Tasks:
     - TODO: change all prints to verbose_prints
 """
 
-import os
-import sys
-import time
-import json
-import datetime
 import collections
+import datetime
+import json
+import os
+import platform
 import resource
-import tempfile
+import socket
 import subprocess
+import sys
+import tempfile
+import time
 import types
-
-from typing import Union
 from io import StringIO
+from typing import Union
 
 import h5py
 import humanize
 import numpy as np
 import psutil
-from colorama import Fore, Back, Style
+from colorama import Back, Fore, Style
 
 from binarycpython import _binary_c_bindings
 from binarycpython.utils.dicts import filter_dict_through_values
@@ -36,6 +37,21 @@ from binarycpython.utils.dicts import filter_dict_through_values
 ########################################################
 
 
+def calculate_total_mass_system(system_dict):
+    """
+    Function to calculate the total mass of the system
+    """
+
+    total_mass = (
+        system_dict.get("M_1", 0)
+        + system_dict.get("M_2", 0)
+        + system_dict.get("M_3", 0)
+        + system_dict.get("M_4", 0)
+    )
+
+    return total_mass
+
+
 def now(now_object=None, style=None, custom_format=None):
     """
     convenience function to return a string of the current time, using the format ``%m/%d/%Y %H:%M:%S``
@@ -700,7 +716,7 @@ def get_defaults(filter_values: bool = False) -> dict:
     default_dict = {}
 
     for default in default_output.split("\n"):
-        if not default in ["__ARG_BEGIN", "__ARG_END", ""]:
+        if default not in ["__ARG_BEGIN", "__ARG_END", ""]:
             key, value = default.split(" = ")
             default_dict[key] = value
 
@@ -1067,7 +1083,7 @@ def make_build_text() -> str:
     Returns:
         string containing information about the build and the git branch
     """
-    from binarycpython.utils.grid import Population
+    from binarycpython.utils.population_class import Population
 
     version_pop = Population()
     version_info = version_pop.return_binary_c_version_info(parsed=True)
@@ -1160,7 +1176,7 @@ def write_binary_c_parameter_descriptions_to_rst_file(output_file: str) -> None:
 ########################################################
 
 
-def load_logfile(logfile: str) -> None: # pragma: no cover
+def load_logfile(logfile: str) -> None:  # pragma: no cover
     """
     Experimental function that parses the generated log file of binary_c.
 
@@ -1210,14 +1226,29 @@ def load_logfile(logfile: str) -> None: # pragma: no cover
 
     print(event_list)
 
+
 def quotewrap(list):
     """
     Given a list, wrap each item in double quotes and return the new list
     """
     return ['"' + _x + '"' for _x in list]
 
+
 def command_string_from_list(list):
     """
     Given a list, turn it into a quoted command string
     """
-    return ' '.join(quotewrap(list))
+    return " ".join(quotewrap(list))
+
+
+def hostnames():
+    """
+    Return a list of possible hostnames for this machine
+    """
+    return [
+        os.getenv("HOSTNAME"),
+        platform.uname()[1],
+        socket.gethostname(),
+        socket.getfqdn(socket.gethostname()),
+        platform.node(),
+    ]
