@@ -21,20 +21,18 @@ Tasks
     TODO: This module is not finished yet.
     TODO: Make modules for single system
     TODO: Put all the plotting functions in here
-
 """
 
 import math
 
-import pandas as pd
-import numpy as np
 import astropy.constants as const
-
 import matplotlib.pyplot as plt
+import numpy as np
+import pandas as pd
 
+from binarycpython.utils.custom_logging_functions import binary_c_log_code
 from binarycpython.utils.functions import output_lines
 from binarycpython.utils.run_system_wrapper import run_system
-from binarycpython.utils.custom_logging_functions import binary_c_log_code
 
 # Define the custom_logging_strings.
 # These are kept to the minimum necessary for each plotting routine.
@@ -43,7 +41,7 @@ CUSTOM_LOGGING_STRING_MASSES = """
 Printf("MASS_PLOTTING %30.12e %g %g %g %g %g %g\\n",
     //
     stardata->model.time, // 1
-    
+
     // masses
     stardata->common.zero_age.mass[0], //
     stardata->common.zero_age.mass[1], //
@@ -59,7 +57,7 @@ CUSTOM_LOGGING_STRING_ORBIT = """
 Printf("ORBIT_PLOTTING %30.12e %g %g %g\\n",
     //
     stardata->model.time, // 1
-    
+
     // orbit elements
     stardata->common.orbit.period, //2
     stardata->common.orbit.separation, //3
@@ -71,7 +69,7 @@ CUSTOM_LOGGING_STRING_HR_DIAGRAM = """
 Printf("HR_PLOTTING %30.12e %d %d %g %g %g %g %g %g\\n",
     //
     stardata->model.time, // 1
-    
+
     // stellar types
     stardata->star[0].stellar_type, //2
     stardata->star[1].stellar_type, //3
@@ -580,10 +578,10 @@ def plot_system(plot_type, **kwargs):
             "parse_function": parse_function_hr_diagram,
         },
     }
-    plot_system_specific_keywords = ["plot_type", "show_plot", "show_stellar_types"]
+    # plot_system_specific_keywords = ["plot_type", "show_plot", "show_stellar_types"]
 
     # First check on the plot_type input
-    if not plot_type in plot_types_dict:
+    if plot_type not in plot_types_dict:
         print(
             "Warning, the provided plot type is not known. \
             Please choose one from the following:\n\t{}".format(
