@@ -17,12 +17,9 @@ import glob
 import json
 import os
 
-from binarycpython.utils.functions import (
-    now,
-)
-
-from binarycpython.utils.population_extensions.slurm import slurm
+from binarycpython.utils.functions import now
 from binarycpython.utils.population_extensions.condor import condor
+from binarycpython.utils.population_extensions.slurm import slurm
 
 
 class HPC(condor, slurm):
@@ -384,7 +381,7 @@ class HPC(condor, slurm):
             dirs = []
         return dirs
 
-    def HPC_grid(self, makejoiningfile=True): # pragma: no cover
+    def HPC_grid(self, makejoiningfile=True):  # pragma: no cover
         """
         Function to call the appropriate HPC grid function
         (e.g. Slurm or Condor) and return what it returns.
@@ -682,14 +679,14 @@ class HPC(condor, slurm):
 
             for i in self.HPC_job_id_range():
                 s = self.HPC_get_status(job_id=_id, job_index=i)
-                #print("HPC get job",_id,':',i," status=",s)
+                # print("HPC get job",_id,':',i," status=",s)
                 if s is None:
                     s = "unknown"
-                if not s in d["status"]:
+                if s not in d["status"]:
                     d["status"][s] = 1
                 else:
                     d["status"][s] += 1
-                if not s in d["joblist"]:
+                if s not in d["joblist"]:
                     d["joblist"][s] = [str(_id) + "." + str(i)]
                 else:
                     d["joblist"][s] += [str(_id) + "." + str(i)]
@@ -711,7 +708,7 @@ class HPC(condor, slurm):
         print(json.dumps(d, indent=4))
         print("############################################################")
 
-    def HPC_queue_stats(self): # pragma: no cover
+    def HPC_queue_stats(self):  # pragma: no cover
         """
         Function that returns the queue stats for the HPC grid
         """
@@ -728,9 +725,11 @@ class HPC(condor, slurm):
     def HPC_job_id_range(self):
         n = self.HPC_njobs()
         if self.grid_options["slurm"] > 0:
-            return range(1, n+1)
+            return range(1, n + 1)
         elif self.grid_options["condor"] > 0:
             return range(0, n)
         else:
-            print("Called HPC_job_id_range when not running an HPC grid : you cannot do this.")
+            print(
+                "Called HPC_job_id_range when not running an HPC grid : you cannot do this."
+            )
             raise
