@@ -2,29 +2,29 @@
 Module containing the functions to handle the Moe&Distrefano data
 
 This class object is an extension to the population grid object
+
+TODO: The values from M&S are from bincenters, but our method makes it that the bincenter value is used as an edge value. So e.g. taking an eccentricity of 0.04 wll give 0 because its lower than the 0.05 (minimum) point. But it should probably give a value, even if we choose eccentricity = 0
 """
 
 # pylint: disable=E1101
 
-import os
-import gc
 import copy
+import gc
 import json
+import os
 
 import py_rinterpolate
 
-from binarycpython.utils.functions import (
-    verbose_print,
-)
-from binarycpython.utils.dicts import update_dicts, normalize_dict
+from binarycpython.utils import moe_di_stefano_2017_data
+from binarycpython.utils.dicts import normalize_dict, update_dicts
+from binarycpython.utils.functions import verbose_print
 from binarycpython.utils.population_extensions.distribution_functions import (
-    Moecache,
     LOG_LN_CONVERTER,
+    Moecache,
 )
 from binarycpython.utils.population_extensions.grid_options_defaults import (
     _MOE2017_VERBOSITY_LEVEL,
 )
-from binarycpython.utils import moe_di_stefano_2017_data
 
 
 class Moe_di_Stefano_2017:
@@ -401,7 +401,7 @@ class Moe_di_Stefano_2017:
         # Setting up the grid variables
 
         # Multiplicity
-        self.add_grid_variable(
+        self.add_sampling_variable(
             name="multiplicity",
             parameter_name="multiplicity",
             longname="multiplicity",
@@ -421,7 +421,7 @@ class Moe_di_Stefano_2017:
         # always require M1, for all systems
         #
         # log-spaced m1 with given resolution
-        self.add_grid_variable(
+        self.add_sampling_variable(
             name="lnM_1",
             parameter_name="M_1",
             longname="Primary mass",
@@ -452,7 +452,7 @@ class Moe_di_Stefano_2017:
         # Go to higher multiplicities
         if max_multiplicity >= 2:
             # binaries: period
-            self.add_grid_variable(
+            self.add_sampling_variable(
                 name="log10per",
                 parameter_name="orbital_period",
                 longname="log10(Orbital_Period)",
@@ -484,7 +484,7 @@ qmax=maximum_mass_ratio_for_RLOF(M_1, orbital_period)
             )  # TODO: change the maximum_mass_ratio_for_RLOF
 
             # binaries: mass ratio
-            self.add_grid_variable(
+            self.add_sampling_variable(
                 name="q",
                 parameter_name="M_2",
                 longname="Mass ratio",
@@ -525,7 +525,7 @@ sep = calc_sep_from_period(M_1, M_2, orbital_period)
 
             # (optional) binaries: eccentricity
             if self.grid_options["Moe2017_options"]["resolutions"]["ecc"][0] > 0:
-                self.add_grid_variable(
+                self.add_sampling_variable(
                     name="ecc",
                     parameter_name="eccentricity",
                     longname="Eccentricity",
@@ -554,7 +554,7 @@ sep = calc_sep_from_period(M_1, M_2, orbital_period)
             # Now for triples and quadruples
             if max_multiplicity >= 3:
                 # Triple: period
-                self.add_grid_variable(
+                self.add_sampling_variable(
                     name="log10per2",
                     parameter_name="orbital_period_triple",
                     longname="log10(Orbital_Period2)",
@@ -587,7 +587,7 @@ q2max=maximum_mass_ratio_for_RLOF(M_1+M_2, orbital_period_triple)
 
                 # Triples: mass ratio
                 # Note, the mass ratio is M_outer/M_inner
-                self.add_grid_variable(
+                self.add_sampling_variable(
                     name="q2",
                     parameter_name="M_3",
                     longname="Mass ratio outer/inner",
@@ -631,7 +631,7 @@ eccentricity2=0
 
                 # (optional) triples: eccentricity
                 if self.grid_options["Moe2017_options"]["resolutions"]["ecc"][1] > 0:
-                    self.add_grid_variable(
+                    self.add_sampling_variable(
                         name="ecc2",
                         parameter_name="eccentricity2",
                         longname="Eccentricity of the triple",
@@ -661,7 +661,7 @@ eccentricity2=0
 
                 if max_multiplicity == 4:
                     # Quadruple: period
-                    self.add_grid_variable(
+                    self.add_sampling_variable(
                         name="log10per3",
                         parameter_name="orbital_period_quadruple",
                         longname="log10(Orbital_Period3)",
@@ -695,7 +695,7 @@ q3max=maximum_mass_ratio_for_RLOF(M_3, orbital_period_quadruple)
                     )
 
                     # Quadruple: mass ratio : M_outer / M_inner
-                    self.add_grid_variable(
+                    self.add_sampling_variable(
                         name="q3",
                         parameter_name="M_4",
                         longname="Mass ratio outer low/outer high",
@@ -742,7 +742,7 @@ eccentricity3=0
                         self.grid_options["Moe2017_options"]["resolutions"]["ecc"][2]
                         > 0
                     ):
-                        self.add_grid_variable(
+                        self.add_sampling_variable(
                             name="ecc3",
                             parameter_name="eccentricity3",
                             longname="Eccentricity of the triple+quadruple/outer binary",
@@ -800,7 +800,7 @@ eccentricity3=0
         )
 
         # and finally the probability calculator
-        self.grid_options["_grid_variables"][self._last_grid_variable()][
+        self.grid_options["_sampling_variables"][self._last_sampling_variable()][
             "probdist"
         ] = probdist_addition
 
@@ -981,9 +981,7 @@ eccentricity3=0
             raise ValueError(msg)
 
         # To make sure we normalize the dictionary
-        multiplicity_fraction_dict = normalize_dict(
-            multiplicity_fraction_dict, verbosity=self.grid_options["verbosity"]
-        )
+        multiplicity_fraction_dict = normalize_dict(multiplicity_fraction_dict)
 
         verbose_print(
             "Multiplicity: {} multiplicity_fraction: {}".format(
