@@ -7,20 +7,17 @@ TODO: there are many uses of $<variable name> in this file but this is not perl
 # pylint: disable=E1101
 
 import os
-import re
-import sys
-import stat
-import time
-import subprocess
-
 import pathlib
+import re
+import stat
+import subprocess
+import sys
+import time
 
 import datasize
 import lib_programname
-from binarycpython.utils.functions import (
-    command_string_from_list,
-    now,
-)
+
+from binarycpython.utils.functions import command_string_from_list
 
 
 class condor:
@@ -219,7 +216,7 @@ class condor:
                     time.sleep(1)
                     break
 
-    def condor_grid(self): # pragma: no cover
+    def condor_grid(self):  # pragma: no cover
         """
         function to be called when running grids when grid_options['condor']>=1
 
@@ -274,12 +271,12 @@ class condor:
                 else "$ClusterID"
             )
 
-            # get job array index
-            Process = (
-                self.grid_options["condor_Process"]
-                if self.grid_options["condor_Process"] != ""
-                else "$Process"
-            )
+            # # get job array index
+            # Process = (
+            #     self.grid_options["condor_Process"]
+            #     if self.grid_options["condor_Process"] != ""
+            #     else "$Process"
+            # )
 
             if self.grid_options["condor_njobs"] == 0:
                 print(
@@ -377,7 +374,7 @@ echo \"running\" > "{condor_dir}/status/$ClusterID.$ProcessID"
                 )
                 condor_job_script += """&& echo \"Checking if we can join...\" && echo && {grid_command} "condor=3" "evolution_type=join" "joinlist={joinfile}" "condor_ClusterID=$ClusterID" "condor_Process=$Process"
                 """.format(
-                    bash=self.grid_options["condor_bash"],
+                    # bash=self.grid_options["condor_bash"],
                     grid_command=grid_command,
                     joinfile=joinfile,
                 )
@@ -525,7 +522,7 @@ queue {njobs}
         # return True so we exit immediately
         return True
 
-    def condor_queue_stats(self): # pragma: no cover
+    def condor_queue_stats(self):  # pragma: no cover
         """
         Return condor queue statistics for this job
         """
@@ -557,7 +554,7 @@ queue {njobs}
             "suspended",
         ]:
             print("Q x ", x)
-            m = re.search("(\d+)\s+{}".format(x), result)
+            m = re.search("(\d+)\s+{}".format(x), result)  # noqa: W605
             print("Q m ", m)
             if m:
                 d[x] = m.group(0)
