@@ -4,28 +4,23 @@ File containing the class extension for the population object that contains data
 
 # pylint: disable=E1101
 
-import os
 import bz2
-import gzip
 import copy
-import json
-import time
 import datetime
+import gzip
+import json
+import os
 import subprocess
+import time
 from typing import Union
 
-import msgpack
-import flufl.lock
 import compress_pickle
+import flufl.lock
+import msgpack
 
-from binarycpython.utils.ensemble import ensemble_file_type, ensemble_compression
-from binarycpython.utils.dicts import (
-    merge_dicts,
-)
-from binarycpython.utils.functions import (
-    verbose_print,
-    now,
-)
+from binarycpython.utils.dicts import merge_dicts
+from binarycpython.utils.ensemble import ensemble_file_type
+from binarycpython.utils.functions import now, verbose_print
 
 
 class dataIO:
@@ -68,6 +63,8 @@ class dataIO:
         https://lucianopaz.github.io/compress_pickle/html/
 
         Shared memory, stored in the population_object.shared_memory dict, is not saved.
+
+        TODO: this function isnt called correctly. grep and find the calls
         """
 
         if population_object is None:
@@ -107,7 +104,7 @@ class dataIO:
             population_object.persistent_data_memory_dict = None
 
             # add metadata if it doesn't exist
-            if not "metadata" in population_object.grid_ensemble_results:
+            if "metadata" not in population_object.grid_ensemble_results:
                 population_object.grid_ensemble_results["metadata"] = {}
 
             # add datestamp
@@ -175,11 +172,10 @@ class dataIO:
         Note:
             The file should be saved using save_population_object()
         """
-        
+
         # combine data
-        refpop.grid_results = merge_dicts(refpop.grid_results,
-                                          newpop.grid_results)
-        
+        refpop.grid_results = merge_dicts(refpop.grid_results, newpop.grid_results)
+
         # special cases
         maxmem = 0
         if "max_memory_use" in refpop.grid_ensemble_results.get(
@@ -210,8 +206,7 @@ class dataIO:
 
             # merge the ensemble dicts
             refpop.grid_ensemble_results = merge_dicts(
-                refpop.grid_ensemble_results,
-                newpop.grid_ensemble_results
+                refpop.grid_ensemble_results, newpop.grid_ensemble_results
             )
 
             # set special cases
@@ -262,9 +257,9 @@ class dataIO:
             n = newpop.grid_ensemble_results["metadata"]["_count"]
         else:
             n = -1
-        
+
         print("Loaded data from {n} stars".format(n=n))
-        
+
         # merge with refpop
         self.merge_populations(refpop, newpop)
 
@@ -417,7 +412,7 @@ class dataIO:
 
         Also, make sure that in this export there are the basic parameters
         like m1,m2,sep, orb-per, ecc, probability etc.
-
+        TODO: this function can probably be cleaned a bit and can rely on the other startup and clean up functions (see population_class)
         On default this will write to the datadir, if it exists
 
         Args:
@@ -444,7 +439,7 @@ class dataIO:
                         raise ValueError
 
             # Put in check
-            if len(self.grid_options["_grid_variables"]) == 0:
+            if len(self.grid_options["_sampling_variables"]) == 0:
                 print("Error: you haven't defined any grid variables! Aborting")
                 raise ValueError
 
