@@ -4,28 +4,26 @@ The class extension for the population object that contains logging functionalit
 
 # pylint: disable=E1101
 
+import logging
 import os
 import sys
 import time
-import logging
+
 import strip_ansi
 
-import binarycpython.utils.functions
-
+from binarycpython.utils.custom_logging_functions import (
+    autogen_C_logging_code,
+    binary_c_log_code,
+    create_and_load_logging_function,
+)
 from binarycpython.utils.functions import (
     format_number,
-    trem,
     remove_file,
+    trem,
     verbose_print,
 )
 from binarycpython.utils.population_extensions.grid_options_defaults import secs_per_day
 
-from binarycpython.utils.custom_logging_functions import (
-    binary_c_log_code,
-    create_and_load_logging_function,
-    autogen_C_logging_code,
-)
-
 
 class grid_logging:
     """
@@ -368,8 +366,8 @@ class grid_logging:
 
         # make a list of strings
         if separator:
-            for l in stringlist:
-                strings += l.split(sep=separator)
+            for string in stringlist:
+                strings += string.split(sep=separator)
         else:
             strings = stringlist
 
