@@ -13,6 +13,7 @@ With this its also possible to automatically generate a document containing all
 All the options starting with _ should not be changed by the user except when you really know what you're doing (which is probably hacking the code :P)
 
 TODO: reconsider having this all as class methods. It seems unnecessary to have all these functions as class methods.
+TODO: rewrite to value-description based dictionary entries rather than two separate things
 """
 
 # pylint: disable=E1101
@@ -22,10 +23,7 @@ import shutil
 import sys
 
 from binarycpython.utils.custom_logging_functions import temp_dir
-from binarycpython.utils.functions import (
-    command_string_from_list,
-    now,
-)
+from binarycpython.utils.functions import command_string_from_list, now
 
 _MOE2017_VERBOSITY_LEVEL = 5
 _MOE2017_VERBOSITY_INTERPOLATOR_LEVEL = 6
@@ -56,7 +54,7 @@ class grid_options_defaults:
             ##########################
             # general (or unordered..)
             ##########################
-            "num_cores": 1,  # total number of cores used to evolve the population
+            "num_cores": None,  # total number of cores used to evolve the population (None -> use all logical cores)
             "num_cores_available": None,  # set automatically, not by the user
             "parse_function": None,  # Function to parse the output with.
             "multiplicity_fraction_function": 0,  # Which multiplicity fraction function to use. 0: None, 1: Arenou 2010, 2: Rhagavan 2010, 3: Moe and di Stefano 2017
@@ -76,7 +74,6 @@ class grid_options_defaults:
             "do_dry_run": True,  # Whether to do a dry run to calculate the total probability for this run
             "dry_run_num_cores": 1,  # number of parallel processes for the dry run (outer loop)
             "dry_run_hook": None,  # Function hook for the dry run: this function is called, if not None, for every star in the dry run. Useful for checking initial distributions.
-            "custom_generator": None,  # Place for the custom system generator
             "return_after_dry_run": False,  # Return immediately after a dry run?
             "exit_after_dry_run": False,  # Exit after dry run?
             "print_stack_on_exit": False,  # print the stack trace on exit calls?
@@ -146,10 +143,11 @@ class grid_options_defaults:
             "_evolution_type_options": [
                 "grid",
                 "custom_generator",
-            ],  # available choices for type of population evolution. # TODO: fill later with Monte Carlo, source file
+                "source_file",
+                "monte_carlo",
+            ],  # available choices for type of population evolution.
             "_system_generator": None,  # value that holds the function that generates the system
             # (result of building the grid script)
-            "source_file_filename": None,  # filename for the source
             "_count": 0,  # count of systems
             "_total_starcount": 0,  # Total count of systems in this generator
             "_probtot": 0,  # total probability
@@ -163,14 +161,16 @@ class grid_options_defaults:
             "_failed_prob": 0,  # Summed probability of failed systems
             "failed_systems_threshold": 20,  # Maximum failed systems per process allowed to fail before the process stops logging the failing systems.
             "_failed_systems_error_codes": [],  # List to store the unique error codes
+            "log_failed_systems": False,  # Flag to enable logging of failed systems...
+            "log_failed_systems_dir": None,  # log them to this dir
             "_population_id": 0,  # Random id of this grid/population run, Unique code for the population. Should be set only once by the controller process.
             "_total_mass_run": 0,  # To count the total mass that thread/process has ran
             "_total_probability_weighted_mass_run": 0,  # To count the total mass * probability for each system that thread/process has ran
             "modulo": 1,  # run modulo n of the grid.
             "start_at": 0,  # start at the first model
-            "skip_before" : 0, # skip models before this
+            "skip_before": 0,  # skip models before this
             ## Grid type evolution
-            "_grid_variables": {},  # grid variables
+            "_sampling_variables": {},  # sampling variables
             "gridcode_filename": None,  # filename of gridcode
             "symlink_latest_gridcode": True,  # symlink to latest gridcode
             "save_population_object": None,  # filename to which we should save a pickled grid object as the final thing we do
@@ -183,10 +183,22 @@ class grid_options_defaults:
             "stop_queue": False,
             "_killed": False,
             "_queue_done": False,
-            ## Monte carlo type evolution
-            # TODO: make MC options
-            ## Evolution from source file
-            # TODO: make run from sourcefile options.
+            ########################################
+            # Monte-Carlo sampling options
+            ########################################
+            "monte_carlo_mass_threshold": -1,
+            "_monte_carlo_current_total_mass_evolved": 0,
+            "_monte_carlo_threshold_reached": False,
+            "_monte_carlo_custom_threshold_function": None,
+            "_monte_carlo_generator_filename": None,
+            ########################################
+            # Source file sampling options
+            ########################################
+            "source_file_filename": None,  # filename for the source
+            ########################################
+            # Custom generator sampling options
+            ########################################
+            "custom_generator": None,  # Place for the custom system generator
             ########################################
             # function caching options
             ########################################
@@ -247,7 +259,7 @@ class grid_options_defaults:
             "slurm_jobarrayindex": None,  # slurm job array index (%a)
             "slurm_jobname": "binary_c-python",  # default
             "slurm_partition": None,
-            "slurm_time": '0',  # total time. 0 = infinite time
+            "slurm_time": "0",  # total time. 0 = infinite time
             "slurm_postpone_sbatch": 0,  # if 1: don't submit, just make the script
             "slurm_array": None,  # override for --array, useful for rerunning jobs
             "slurm_array_max_jobs": None,  # override for the max number of concurrent array jobs
@@ -330,7 +342,7 @@ class grid_options_defaults:
             "_evolution_type_options": "List containing the evolution type options.",
             "_failed_prob": "Variable storing the total probability of all the failed systems",
             "_failed_systems_error_codes": "List storing the unique error codes raised by binary_c of the failed systems",
-            "_grid_variables": "Dictionary storing the grid_variables. These contain properties which are accessed by the _generate_grid_code function",
+            "_sampling_variables": "Dictionary storing the sampling_variables. These contain properties which are accessed by the _generate_grid_code function",
             "_population_id": "Variable storing a unique 32-char hex string.",
             "_commandline_input": "String containing the arguments passed to the population object via the command line. Set and used by the population object.",
             "_system_generator": "Function object that contains the system generator function. This can be from a grid, or a source file, or a Monte Carlo grid.",
@@ -623,6 +635,6 @@ class grid_options_defaults:
             os.path.join(os.environ.get("HOME", error_string), ".cache", "binary_c"),
             os.path.join(os.environ.get("TMP", error_string), "cache"),
         ]:
-            if not error_string in path and os.path.isdir(path):
+            if error_string not in path and os.path.isdir(path):
                 return path
         return None
