@@ -7,18 +7,16 @@ This class object is an extension to the population grid object
 # pylint: disable=E1101
 
 import os
+import pathlib
+import stat
+import subprocess
 import sys
 import time
-import stat
-import pathlib
-import subprocess
 
 import datasize
 import lib_programname
-from binarycpython.utils.functions import (
-    command_string_from_list,
-    now,
-)
+
+from binarycpython.utils.functions import command_string_from_list
 
 
 class slurm:
@@ -114,8 +112,8 @@ class slurm:
                 f.close()
                 self.NFS_flush_hack(status_file)
 
-        print("Have set status in",status_file,"to",string)
-        with self.open(status_file,"r",encoding="utf-8") as f:
+        print("Have set status in", status_file, "to", string)
+        with self.open(status_file, "r", encoding="utf-8") as f:
             print("Contents")
             print(f.readlines())
             f.close()
@@ -215,7 +213,7 @@ class slurm:
                     time.sleep(1)
                     break
 
-    def slurm_grid(self): # pragma: no cover
+    def slurm_grid(self):  # pragma: no cover
         """
         function to be called when running grids when grid_options['slurm']>=1
 
@@ -273,14 +271,6 @@ class slurm:
                     max_jobs=self.grid_options["slurm_array_max_jobs"],
                 )
 
-            # get job id (might be passed in)
-            # TODO: is this variable used?
-            jobid = (
-                self.grid_options["slurm_jobid"]
-                if self.grid_options["slurm_jobid"] != ""
-                else "$SLURM_ARRAY_JOB_ID"
-            )
-
             # get job array index
             jobarrayindex = self.grid_options["slurm_jobarrayindex"]
             if jobarrayindex is None:
@@ -454,7 +444,7 @@ echo \"running\" > "{slurm_dir}/status/$SLURM_ARRAY_JOB_ID.$SLURM_ARRAY_TASK_ID"
         # return True so we exit immediately
         return True
 
-    def slurm_queue_stats(self): # pragma: no cover
+    def slurm_queue_stats(self):  # pragma: no cover
         """
         Function to XXX
 
