@@ -9,19 +9,16 @@ Tasks:
 
 # pylint: disable=E1101
 
-import sys
-import math
-import json
 import functools
-from typing import Union
+import json
+import math
+import sys
 import traceback
+from typing import Union
 
-import numpy as np
 import cachetools
 import diskcache
-
-
-
+import numpy as np
 import py_rinterpolate
 
 
@@ -128,7 +125,7 @@ class spacing_functions:
 
         r = 1.0 / sigma
         y = (x - mean) * r
-        return gaussian_prefactor * math.exp(-0.5 * y ** 2)
+        return gaussian_prefactor * math.exp(-0.5 * y**2)
 
     ############################################################
     @cachetools.cachedmethod(
@@ -345,14 +342,14 @@ class spacing_functions:
                 return func(*args, **kwargs)
 
             return wrapped
-                
+
         if cache is not None:
             __decorator = cache.memoize
         else:
             __decorator = __dummy_decorator
 
-        #@cache.memoize()    
-        @__decorator() # note: () works with python3.9+, maybe not for 3.8
+        # @cache.memoize()
+        @__decorator()  # note: () works with python3.9+, maybe not for 3.8
         def _const_dt(
             cachedir=None,
             num_cores=None,
@@ -392,8 +389,8 @@ class spacing_functions:
             # perhaps override max_evolution_time
             if max_evolution_time:
                 bse_options["max_evolution_time"] = max_evolution_time
+            from binarycpython.utils.population_class import Population
 
-            from binarycpython.utils.grid import Population
             lifetime_population = Population()
             lifetime_population.bse_options = bse_options
 
@@ -420,7 +417,7 @@ class spacing_functions:
             )
 
             # make a grid in M1
-            lifetime_population.add_grid_variable(
+            lifetime_population.add_sampling_variable(
                 name="lnM_1",
                 parameter_name="M_1",
                 longname="log Primary mass",  # == single-star mass
@@ -590,7 +587,7 @@ class spacing_functions:
                 logt = math.log10(t)
                 logtmin = math.log10(tmin)
                 while logt > logtmin:
-                    m = _mass_from_time(10.0 ** logt)
+                    m = _mass_from_time(10.0**logt)
                     mass_list.append(m)
                     logt = max(logtmin, logt - dlogt * fsample)
             else:
